pub struct VmoCreateVmoRequest {
pub size: u64,
pub options: VmoOptions,
pub handle: NewHandleId,
}Fields
size: u64options: VmoOptionshandle: NewHandleIdTrait Implementations
Sourceimpl Clone for VmoCreateVmoRequest
impl Clone for VmoCreateVmoRequest
Sourcefn clone(&self) -> VmoCreateVmoRequest
fn clone(&self) -> VmoCreateVmoRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for VmoCreateVmoRequest
Sourceimpl Debug for VmoCreateVmoRequest
impl Debug for VmoCreateVmoRequest
Sourceimpl<D: ResourceDialect> Decode<VmoCreateVmoRequest, D> for VmoCreateVmoRequest
impl<D: ResourceDialect> Decode<VmoCreateVmoRequest, D> for VmoCreateVmoRequest
Sourceimpl<D: ResourceDialect> Encode<VmoCreateVmoRequest, D> for &VmoCreateVmoRequest
impl<D: ResourceDialect> Encode<VmoCreateVmoRequest, D> for &VmoCreateVmoRequest
Sourceimpl<D: ResourceDialect, T0: Encode<u64, D>, T1: Encode<VmoOptions, D>, T2: Encode<NewHandleId, D>> Encode<VmoCreateVmoRequest, D> for (T0, T1, T2)
impl<D: ResourceDialect, T0: Encode<u64, D>, T1: Encode<VmoOptions, D>, T2: Encode<NewHandleId, D>> Encode<VmoCreateVmoRequest, D> for (T0, T1, T2)
impl Eq for VmoCreateVmoRequest
Sourceimpl Hash for VmoCreateVmoRequest
impl Hash for VmoCreateVmoRequest
Sourceimpl Ord for VmoCreateVmoRequest
impl Ord for VmoCreateVmoRequest
Sourcefn cmp(&self, other: &VmoCreateVmoRequest) -> Ordering
fn cmp(&self, other: &VmoCreateVmoRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for VmoCreateVmoRequest
impl PartialEq for VmoCreateVmoRequest
Sourceimpl PartialOrd for VmoCreateVmoRequest
impl PartialOrd for VmoCreateVmoRequest
impl Persistable for VmoCreateVmoRequest
impl StructuralPartialEq for VmoCreateVmoRequest
Sourceimpl TypeMarker for VmoCreateVmoRequest
impl TypeMarker for VmoCreateVmoRequest
Sourcetype Owned = VmoCreateVmoRequest
type Owned = VmoCreateVmoRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for VmoCreateVmoRequest
impl ValueTypeMarker for VmoCreateVmoRequest
Sourcetype Borrowed<'a> = &'a VmoCreateVmoRequest
type Borrowed<'a> = &'a VmoCreateVmoRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for VmoCreateVmoRequest
impl RefUnwindSafe for VmoCreateVmoRequest
impl Send for VmoCreateVmoRequest
impl Sync for VmoCreateVmoRequest
impl Unpin for VmoCreateVmoRequest
impl UnsafeUnpin for VmoCreateVmoRequest
impl UnwindSafe for VmoCreateVmoRequest