#[repr(C)]pub struct VmoSetVmoStreamSizeRequest {
pub handle: HandleId,
pub size: u64,
}Fields
handle: HandleIdsize: u64Trait Implementations
Sourceimpl Clone for VmoSetVmoStreamSizeRequest
impl Clone for VmoSetVmoStreamSizeRequest
Sourcefn clone(&self) -> VmoSetVmoStreamSizeRequest
fn clone(&self) -> VmoSetVmoStreamSizeRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for VmoSetVmoStreamSizeRequest
Sourceimpl Debug for VmoSetVmoStreamSizeRequest
impl Debug for VmoSetVmoStreamSizeRequest
Sourceimpl<D: ResourceDialect> Decode<VmoSetVmoStreamSizeRequest, D> for VmoSetVmoStreamSizeRequest
impl<D: ResourceDialect> Decode<VmoSetVmoStreamSizeRequest, D> for VmoSetVmoStreamSizeRequest
Sourceimpl<D: ResourceDialect> Encode<VmoSetVmoStreamSizeRequest, D> for &VmoSetVmoStreamSizeRequest
impl<D: ResourceDialect> Encode<VmoSetVmoStreamSizeRequest, D> for &VmoSetVmoStreamSizeRequest
Sourceimpl<D: ResourceDialect, T0: Encode<HandleId, D>, T1: Encode<u64, D>> Encode<VmoSetVmoStreamSizeRequest, D> for (T0, T1)
impl<D: ResourceDialect, T0: Encode<HandleId, D>, T1: Encode<u64, D>> Encode<VmoSetVmoStreamSizeRequest, D> for (T0, T1)
impl Eq for VmoSetVmoStreamSizeRequest
Sourceimpl Hash for VmoSetVmoStreamSizeRequest
impl Hash for VmoSetVmoStreamSizeRequest
Sourceimpl Ord for VmoSetVmoStreamSizeRequest
impl Ord for VmoSetVmoStreamSizeRequest
Sourcefn cmp(&self, other: &VmoSetVmoStreamSizeRequest) -> Ordering
fn cmp(&self, other: &VmoSetVmoStreamSizeRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for VmoSetVmoStreamSizeRequest
impl PartialOrd for VmoSetVmoStreamSizeRequest
impl Persistable for VmoSetVmoStreamSizeRequest
impl StructuralPartialEq for VmoSetVmoStreamSizeRequest
Sourceimpl TypeMarker for VmoSetVmoStreamSizeRequest
impl TypeMarker for VmoSetVmoStreamSizeRequest
Sourcetype Owned = VmoSetVmoStreamSizeRequest
type Owned = VmoSetVmoStreamSizeRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for VmoSetVmoStreamSizeRequest
impl ValueTypeMarker for VmoSetVmoStreamSizeRequest
Sourcetype Borrowed<'a> = &'a VmoSetVmoStreamSizeRequest
type Borrowed<'a> = &'a VmoSetVmoStreamSizeRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for VmoSetVmoStreamSizeRequest
impl RefUnwindSafe for VmoSetVmoStreamSizeRequest
impl Send for VmoSetVmoStreamSizeRequest
impl Sync for VmoSetVmoStreamSizeRequest
impl Unpin for VmoSetVmoStreamSizeRequest
impl UnsafeUnpin for VmoSetVmoStreamSizeRequest
impl UnwindSafe for VmoSetVmoStreamSizeRequest